
# == == == == == == == == == == == == == == == == == == == == == == == == == ==
# 
# This script is written to estimate the incubation period and serial interval
# of the novel SARS-CoV-2 with data from Bavaria, Germany. Data stems from
# notification data collected from Jan 20 to March 20. 
# 
# == == == == == == == == == == == == == == == == == == == == == == == == == ==



#### Read data and Libraries ####

# libraries
library(dplyr)
library(tidyr)
library(lubridate)
library(ggplot2)
library(survminer)
library(survival)
library(icenReg)
library(mixdist)
library(ggraph)
library(tidygraph)

# data:

# incubation period
incu <- read.table("Incubation_period_Bavaria.csv",
                        dec = ".", 
                        sep = ";",
                        header = TRUE)


# Serial interval
serial <- read.table("Serial_interval_Bavaria.csv",
                        dec = ".", 
                        sep = ";",
                        header = TRUE)
# A bit of data cleaning

# incubation period

glimpse(incu)

incu$left_expo2 <- dmy(incu$left_expo2)
incu$right_expo2 <- dmy(incu$right_expo2)
incu$date_of_onset <- dmy(incu$date_of_onset)
summary(incu$date_of_onset)

# serial interval

glimpse(serial)

serial$first <- dmy(serial$first)
serial$second <- dmy(serial$second)


#### Estimation of incubation period ####


# Estimate minimum and maximum of incubation period
          incumin <- as.numeric(incu$date_of_onset - incu$right_expo2)
          incumax <- as.numeric(incu$date_of_onset - incu$left_expo2)
          hist(incumax)
          hist(incumin)
          incu$incumin <- incumin
          incu$incumax <- incumax

# naive estimate incubation period, suppose everyone got infected at the middle 
# of the exposure period
          
          incu$naive_incu <- (incu$incumin + incu$incumax)/2
          
          ggplot(incu, aes(x = naive_incu)) +
            geom_bar(alpha = 0.4) + xlab("naive estimated incubation period")
# Kaplan meier plot taking account of intervals of exposure
          ggsurvplot(
            fit = survfit(Surv(incumin, incumax, type="interval2") ~ 1, 
                          data = incu), 
            xlab = "Days",
            ylab = "Overall probability of no symptoms yet")

# Estimates from the log-normal distribution:          

          myfit.ln <- ic_par(Surv(incu$incumin, incu$incumax, type="interval2") ~ 1, 
                             data = incu, dist = "lnorm")
          
          incqs.ln <- getFitEsts(myfit.ln, newdata = NULL, 
                                 p = c(0.025, 0.05, 0.25, 0.5, 0.75, 0.95, 0.975))
          days <-  seq(0, 30, by = 0.05)
          density.ln <- dlnorm(days, meanlog = myfit.ln$coefficients[1], 
                               sdlog = exp(myfit.ln$coefficients[2]))
# Median
          incqs.ln  

# log likelihood:
          myfit.ln$llk 
          
# estimated parameters:
          meanlog.est = myfit.ln$coefficients[1]
          sdlog.est = exp(myfit.ln$coefficients[2])
          # ic_par result myfit.ln$coefficients[2] is log of the sdlog, be careful with that          
# mean and sd of log normal estimates:

          # mean:
          # exp(myfit.ln$coefficients[1] + 0.5*exp(myfit.ln$coefficients[2])^2) 
          exp(meanlog.est + 0.5*(sdlog.est^2)) 
          # mean = 4.6
          # sd
          # sqrt((exp(myfit.ln$coefficients[2]^2) - 1) * exp(2*myfit.ln$coefficients[1] + myfit.ln$coefficients[2]^2))
          sqrt((exp(sdlog.est^2) - 1)*exp(2*meanlog.est + sdlog.est^2))
          # sd = 3.0
            
# get the confidence interval of our estimates using bootstrap:
ci <- survCIs(myfit.ln, p = seq(0, 1, 0.0125), ci_level = 0.95) 

ci <- ci$cis
ci <- ci$baseline
upper <- ci[,5]
lower <- ci[,4]

# show the confidence interval of estimated median incubation and 95% quantile
survCIs(myfit.ln, p = c(0.5, 0.95), ci_level = 0.95)
# 3.8 (3.5, 4.2); 10.3 (9.1, 11.8)

#### Visualization incubation period - Figure 3 ####

# Kaplan meier plot:
        ggs <- ggsurvplot(
          fit = survfit(Surv(incu$incumin, incu$incumax, type = "interval2") ~ 1, data = incu), 
          xlab = "Days since exposure",  
          ylab = "Proportion of cases with no symptoms yet",
          combine = TRUE,
          legend = c("none"),
          palette = c("#666666"),
          alpha = 0.4)

        tmp <- data.frame(days = days, 
                          fitsurv = 1 - plnorm(days, meanlog = myfit.ln$coefficients[1],
                                               sdlog = exp(myfit.ln$coefficients[2])))
        prob = seq(0, 1, 0.0125)
        
        tmp.upper <- data.frame(days = upper,
                                fitsurv = 1- prob)
        tmp.lower <- data.frame(days = lower,
                                fitsurv = 1- prob)
        tmp.lower <- tmp.lower[2:80,]
        tmp.upper <- tmp.upper[2:80,]

# Final plot:
ggs$plot + geom_line(data = tmp, aes(x = days, y = fitsurv), color = "#386cb0", size = 1.3) +
  geom_line(data = tmp.upper, aes(x = days, y = fitsurv), color = "#386cb0", alpha = 0.7) +
  geom_line(data = tmp.lower, aes(x = days, y = fitsurv), color = "#386cb0", alpha = 0.7) 



#### Incubation period Austria vs Italy and Sup. Fig2  ####


# == == == == == == == == == == == == == == == == == == == == ==
# FILTERS for stratification purposes:
# incu.com <- filter(incu.com, date_of_onset >= ymd("2020.03.09"))
# incu.com <- filter(incu.com, duration > 3)
#incu.com <- filter(incu.com, incu_import == "Italien")
# incu.com <- filter(incu.com, incu_import == "Österreich")
# incu.com <- filter(incu.com, age > 40 & age <= 60)

# Filter imported cases from Austria and Italy
incu.com <- filter(incu, incu_import == "Österreich" | incu_import == "Italien")

# age distribution
ggplot(incu.com, aes(x = age, fill = incu_import)) +
  geom_bar() + xlab("age distribution")



### extract austrian data
incu.com.aus <- incu.com[which(incu.com$incu_import == "Österreich"),]

myfit.ln.aus <- ic_par(Surv(incu.com.aus$incumin, incu.com.aus$incumax, type="interval2") ~ 1,
                       data = incu.com.aus, dist = "lnorm")

# parameter estimation
meanlog.aus <- myfit.ln.aus$coefficients[1]
sdlog.aus <- exp(myfit.ln.aus$coefficients[2])

incqs.ln.aus <- getFitEsts(myfit.ln.aus, newdata = NULL, 
                           p = c(0.025, 0.05, 0.25, 0.5, 0.75, 0.95, 0.975))
myfit.ln.aus 

survCIs(myfit.ln.aus, p = 0.5) 

# mean:
# exp(myfit.ln.aus$coefficients[1] + 0.5*exp(myfit.ln.aus$coefficients[2])^2) 
exp(meanlog.aus + 0.5*(sdlog.aus^2)) 
# mean = 3.7
# sd
# sqrt((exp(myfit.ln.aus$coefficients[2]^2) - 1) * exp(2*myfit.ln.aus$coefficients[1] + myfit.ln.aus$coefficients[2]^2))
sqrt((exp(sdlog.aus^2) - 1)*exp(2*meanlog.aus + sdlog.aus^2))
# sd = 2.1

### extract italy data
incu.com.it <- incu.com[which(incu.com$incu_import == "Italien"),]

myfit.ln.it <- ic_par(Surv(incu.com.it$incumin, incu.com.it$incumax, type="interval2") ~ 1,
                      data = incu.com.it, dist = "lnorm")

survCIs(myfit.ln.it, p = 0.5) 

ggs <- ggsurvplot(
  fit = survfit(Surv(incu.com$incumin, incu.com$incumax, type = "interval2") ~ incu_import, 
                data = incu.com), 
  xlab = "Days",  ylab = "Overall probability of no symptoms yet")

ggs$plot

days <-  seq(0, 30, by = 0.05)

# parameter estimation

meanlog.it <- myfit.ln.it$coefficients[1]
sdlog.it <- exp(myfit.ln.it$coefficients[2])

incqs.ln.it <- getFitEsts(myfit.ln.it, newdata = NULL, 
                          p = c(0.025, 0.05, 0.25, 0.5, 0.75, 0.95, 0.975))
incqs.ln.it 

# mean:
# exp(myfit.ln.it$coefficients[1] + 0.5*exp(myfit.ln.it$coefficients[2])^2) 
exp(meanlog.it + 0.5*(sdlog.it^2))
# mean = 5.6
# sd
# sqrt((exp(myfit.ln.it$coefficients[2]^2) - 1) * exp(2*myfit.ln.it$coefficients[1] + myfit.ln.it$coefficients[2]^2))
sqrt((exp(sdlog.it^2) - 1)*exp(2*meanlog.it + sdlog.it^2))
# sd = 3.8

# get the confidence interval of our estimates using bootstrap: Austria

ci.aus <- survCIs(myfit.ln.aus, p = seq(0, 1, 0.0125)) 

ci.aus <- ci.aus$cis
ci.aus <- ci.aus$baseline
upper.aus <- ci.aus[,5]
lower.aus <- ci.aus[,4]

# Italy
ci.it <- survCIs(myfit.ln.it, p = seq(0, 1, 0.0125)) 

ci.it <- ci.it$cis
ci.it <- ci.it$baseline
upper.it <- ci.it[,5]
lower.it <- ci.it[,4]

# tmp data frame created using ln on austrian data
tmp <- data.frame(days = days, 
                  fitsurv = 1 - plnorm(days, meanlog = myfit.ln.aus$coefficients[1],
                                       sdlog = exp(myfit.ln.aus$coefficients[2])))

# tmp data frame created using ln on italy data
tmp_2 <- data.frame(days = days, 
                    fitsurv = 1 - plnorm(days, meanlog = myfit.ln.it$coefficients[1],
                                         sdlog = exp(myfit.ln.it$coefficients[2])))


# confidence intervals: Austria
prob = seq(0, 1, 0.0125)
tmp.upper.aus <- data.frame(days = upper.aus,
                            fitsurv = 1- prob)
tmp.lower.aus <- data.frame(days = lower.aus,
                            fitsurv = 1- prob)
tmp.lower.aus <- tmp.lower.aus[2:80,]
tmp.upper.aus <- tmp.upper.aus[2:80,]

# confidence intervals: Italy
prob = seq(0, 1, 0.0125)
tmp.upper.it <- data.frame(days = upper.it,
                           fitsurv = 1- prob)
tmp.lower.it <- data.frame(days = lower.it,
                           fitsurv = 1- prob)
tmp.lower.it <- tmp.lower.it[2:80,]
tmp.upper.it <- tmp.upper.it[2:80,]




# fit smooth lines separately of each group
#          ggs$plot + 

#   ggs$plot + geom_line(data = tmp, aes(x = days, y = fitsurv), color = "blue") +
#    geom_line(data = tmp_2, aes(x = days, y = fitsurv), color = "red") 



ggs <- ggsurvplot(
  fit = survfit(Surv(incu.com$incumin, incu.com$incumax, type = "interval2") ~ incu_import, data = incu.com), 
  xlab = "Days since exposure",  
  ylab = "Proportion of cases with no symptoms yet",
  combine = TRUE,
  legend = c("none"),
  palette = c("#2166ac", "#b2182b"),
  alpha = 0.4) 

ggs$plot +
  geom_line(data = tmp, aes(x = days, y = fitsurv), color = "#b2182b", size = 1.2) +
  geom_line(data = tmp_2, aes(x = days, y = fitsurv), color = "#2166ac", size = 1.2) +
  geom_line(data = tmp.upper.aus, aes(x = days, y = fitsurv), color = "#b2182b", alpha = 0.7, linetype = "dashed") +
  geom_line(data = tmp.lower.aus, aes(x = days, y = fitsurv), color = "#b2182b", alpha = 0.7, linetype = "dashed") +
  geom_line(data = tmp.upper.it, aes(x = days, y = fitsurv), color = "#2166ac", alpha = 0.7, linetype = "dashed") +
  geom_line(data = tmp.lower.it, aes(x = days, y = fitsurv), color = "#2166ac", alpha = 0.7, linetype = "dashed") 


# how are the age groups divided

table <-  incu.com %>%
  mutate(age.cat = cut(as.numeric(age), breaks = c(0,10,20,30,40,50,60,Inf))) %>%
  group_by(age.cat, incu_import) %>%
  summarise(n = n()) %>%
  pivot_wider(names_from = age.cat, values_from = n)



#### additional plots ####

incu.com <- incu

# get a range of age and date of onset
summary(incu.com$age)
summary(incu.com$date_of_onset)

# duration
incu.com$duration <- incu.com$incumax - incu.com$incumin
summary(incu.com$duration)        

# create the groups:
q <- quantile(incu.com$age)
incu.com$age.cat <- cut(incu.com$age, breaks = c(q))
table(incu.com$age.cat)  

q <- quantile(incu.com$date_of_onset, type = 1)
incu.com$doo.cat <- cut(incu.com$date_of_onset, breaks = c(q))
table(incu.com$doo.cat)

q <- quantile(incu.com$duration)
incu.com$dur.cat <- cut(incu.com$duration, breaks = c(q))
table(incu.com$dur.cat)


# == == == == == == == == == == == == == == == == == == == == ==
# FILTERS for stratification purposes:

# age
incu.com_1 <- filter(incu.com, age.cat == "(10,32.8]")
incu.com_2 <- filter(incu.com, age.cat == "(32.8,47]")
incu.com_3 <- filter(incu.com, age.cat == "(47,54]")
incu.com_4 <- filter(incu.com, age.cat == "(54,83]")

# doo
incu.com_1 <- filter(incu.com, doo.cat == "2020-02-20")
incu.com_2 <- filter(incu.com, doo.cat == "2020-03-06")
incu.com_3 <- filter(incu.com, doo.cat == "2020-03-09")
incu.com_4 <- filter(incu.com, doo.cat == "2020-03-12")

# duration
incu.com_1 <- filter(incu.com, dur.cat == "(0,3]")
incu.com_2 <- filter(incu.com, dur.cat == "(3,4]")
incu.com_3 <- filter(incu.com, dur.cat == "(4,6]")
incu.com_4 <- filter(incu.com, dur.cat == "(6,41]")


### actual analyses

### fit ln on subsets
myfit.ln_1 <- ic_par(Surv(incu.com_1$incumin, incu.com_1$incumax, type="interval2") ~ 1,
                     data = incu.com_1, dist = "lnorm")
myfit.ln_2 <- ic_par(Surv(incu.com_2$incumin, incu.com_2$incumax, type="interval2") ~ 1,
                     data = incu.com_2, dist = "lnorm")
myfit.ln_3 <- ic_par(Surv(incu.com_3$incumin, incu.com_3$incumax, type="interval2") ~ 1,
                     data = incu.com_3, dist = "lnorm")
myfit.ln_4 <- ic_par(Surv(incu.com_4$incumin, incu.com_4$incumax, type="interval2") ~ 1,
                     data = incu.com_4, dist = "lnorm")

# mean:
exp(myfit.ln_1$coefficients[1] + 0.5*exp(myfit.ln_1$coefficients[2])^2) 
exp(myfit.ln_2$coefficients[1] + 0.5*exp(myfit.ln_2$coefficients[2])^2) 
exp(myfit.ln_3$coefficients[1] + 0.5*exp(myfit.ln_3$coefficients[2])^2) 
exp(myfit.ln_4$coefficients[1] + 0.5*exp(myfit.ln_4$coefficients[2])^2) 


incqs.ln_1 <- getFitEsts(myfit.ln_1, newdata = NULL, 
                         p = c(0.025, 0.05, 0.25, 0.5, 0.75, 0.95, 0.975))
incqs.ln_2 <- getFitEsts(myfit.ln_2, newdata = NULL, 
                         p = c(0.025, 0.05, 0.25, 0.5, 0.75, 0.95, 0.975))
incqs.ln_3 <- getFitEsts(myfit.ln_3, newdata = NULL, 
                         p = c(0.025, 0.05, 0.25, 0.5, 0.75, 0.95, 0.975))
incqs.ln_4 <- getFitEsts(myfit.ln_4, newdata = NULL, 
                         p = c(0.025, 0.05, 0.25, 0.5, 0.75, 0.95, 0.975))
# sd
# sqrt((exp(myfit.ln.aus$coefficients[2]^2) - 1) * exp(2*myfit.ln.aus$coefficients[1] + myfit.ln.aus$coefficients[2]^2))



# get the confidence interval of our estimates using bootstrap: Austria
#
#ci.aus <- survCIs(myfit.ln.aus, p = seq(0, 1, 0.0125)) 
#
#ci.aus <- ci.aus$cis
#ci.aus <- ci.aus$baseline
#upper.aus <- ci.aus[,5]
#lower.aus <- ci.aus[,4]

# Italiaaaa
#ci.it <- survCIs(myfit.ln.it, p = seq(0, 1, 0.0125)) 

#ci.it <- ci.it$cis
#ci.it <- ci.it$baseline
#upper.it <- ci.it[,5]
#lower.it <- ci.it[,4]

# tmp data frame created using ln fits on subsest
tmp_1 <- data.frame(days = days, 
                    fitsurv = 1 - plnorm(days, meanlog = myfit.ln_1$coefficients[1],
                                         sdlog = exp(myfit.ln_1$coefficients[2])))

# tmp data frame created using ln fits on subsest
tmp_2 <- data.frame(days = days, 
                    fitsurv = 1 - plnorm(days, meanlog = myfit.ln_2$coefficients[1],
                                         sdlog = exp(myfit.ln_2$coefficients[2])))
# tmp data frame created using ln fits on subsest
tmp_3 <- data.frame(days = days, 
                    fitsurv = 1 - plnorm(days, meanlog = myfit.ln_3$coefficients[1],
                                         sdlog = exp(myfit.ln_3$coefficients[2])))
# tmp data frame created using ln fits on subsest
tmp_4 <- data.frame(days = days, 
                    fitsurv = 1 - plnorm(days, meanlog = myfit.ln_4$coefficients[1],
                                         sdlog = exp(myfit.ln_4$coefficients[2])))


# confidence intervals: Austria
#prob = seq(0, 1, 0.0125)
#tmp.upper.aus <- data.frame(days = upper.aus,
#                            fitsurv = 1- prob)
#tmp.lower.aus <- data.frame(days = lower.aus,
#                            fitsurv = 1- prob)
#tmp.lower.aus <- tmp.lower.aus[2:80,]
#tmp.upper.aus <- tmp.upper.aus[2:80,]

# confidence intervals: Italia
#prob = seq(0, 1, 0.0125)
#tmp.upper.it <- data.frame(days = upper.it,
#                           fitsurv = 1- prob)
#tmp.lower.it <- data.frame(days = lower.it,
#                           fitsurv = 1- prob)
#tmp.lower.it <- tmp.lower.it[2:80,]
#tmp.upper.it <- tmp.upper.it[2:80,]




# fit smooth lines separately of each group
#          ggs$plot + 

#   ggs$plot + geom_line(data = tmp, aes(x = days, y = fitsurv), color = "blue") +
#    geom_line(data = tmp_2, aes(x = days, y = fitsurv), color = "red") 



ggs <- ggsurvplot(
  fit = survfit(Surv(incu.com$incumin, incu.com$incumax, type = "interval2") ~ incu_import, data = incu.com), 
  xlab = "Days since exposure",  
  ylab = "Proportion of cases without symptoms",
  combine = TRUE,
  legend = c("none"),
  palette = c("#4daf4a","#984ea3"),
  alpha = 0.4) 

# age
EF <- ggplot() +
  labs(x = "Days since exposure", y = "Proportion of cases with no symptoms yet")  +
  theme_classic() +
  scale_x_continuous(limits = c(0, 20)) +
  geom_line(data = tmp_1, aes(x = days, y = fitsurv, color = "(10,32.8]"), size = 1.5) + # , color = "#482173"
  geom_line(data = tmp_2, aes(x = days, y = fitsurv, color = "(32.8,47]"), size = 1.5) + #, color = "#2e6f8e"
  geom_line(data = tmp_3, aes(x = days, y = fitsurv, color = "(47,54]"), size = 1.5) + # , color = "#29af7f"
  geom_line(data = tmp_4, aes(x = days, y = fitsurv, color = "(54,83]"), size = 1.5) +  # , color = "#bddf26"
  scale_color_manual(values = c("(10,32.8]" = "#482173", "(32.8,47]" = "#2e6f8e", "(47,54]" = "#29af7f", "(54,83]" = "#bddf26"),
                     name = "Age group") +
  theme(legend.position = c(.75, .75)) +
  annotate("text", -Inf, Inf, hjust = -0.5, vjust = 1, label = "F", size = 8) 


# DOO
library(viridis)
inferno(n = 4)
E <- ggplot() +
  labs(x = "Days since exposure", y = "Proportion of cases with no symptoms yet")  +
  theme_classic() +
  scale_x_continuous(limits = c(0, 20)) +
  geom_line(data = tmp_1, aes(x = days, y = fitsurv, color = "2020-02-20"), size = 1.5) + # , color = "#482173"
  geom_line(data = tmp_2, aes(x = days, y = fitsurv, color = "2020-03-06"), size = 1.5) + #, color = "#2e6f8e"
  geom_line(data = tmp_3, aes(x = days, y = fitsurv, color = "2020-03-09"), size = 1.5) + # , color = "#29af7f"
  geom_line(data = tmp_4, aes(x = days, y = fitsurv, color = "2020-03-12"), size = 1.5) +  # , color = "#bddf26"
  scale_color_manual(values = c("2020-02-20" = "#000004FF", "2020-03-06" = "#781C6DFF", "2020-03-09" = "#ED6925FF", "2020-03-12" = "#FCFFA4FF"),
                     name = "Date of onset",
                     labels = c("Feb 20 - March 05","March 06 - March 08","March 09 - March 11","March 12 - March 19")) +
  theme(legend.position = c(.75, .75))  +
  annotate("text", -Inf, Inf, hjust = -0.5, vjust = 1, label = "E", size = 8) 
E
# DUR
library(viridis)
plasma(n = 4)
D <- ggplot() +
  labs(x = "Days since exposure", y = "Proportion of cases with no symptoms yet")  +
  theme_classic() +
  scale_x_continuous(limits = c(0, 20)) +
  geom_line(data = tmp_1, aes(x = days, y = fitsurv, color = "(0,3]"), size = 1.5) + # , color = "#482173"
  geom_line(data = tmp_2, aes(x = days, y = fitsurv, color = "(3,4]"), size = 1.5) + #, color = "#2e6f8e"
  geom_line(data = tmp_3, aes(x = days, y = fitsurv, color = "(4,6]"), size = 1.5) + # , color = "#29af7f"
  geom_line(data = tmp_4, aes(x = days, y = fitsurv, color = "(6,41]"), size = 1.5) +  # , color = "#bddf26"
  scale_color_manual(values = c("(0,3]" = "#0D0887FF", "(3,4]" = "#9C179EFF", "(4,6]" = "#ED7953FF", "(6,41]" = "#F0F921FF"),
                     name = "Duration abroad",
                     labels = c("Up until 3 days","4 days","5 - 6 days","7 - 41 days")) +
  theme(legend.position = c(.75, .75)) +
  annotate("text", -Inf, Inf, hjust = -0.5, vjust = 1, label = "D", size = 8) 
D          




#### Additional plots 2 - countries stratified by duration ####

# subsets by duration
      incu.com_dur <- filter(incu.com, dur.cat == "(0,3]")
      incu.com_dur <- filter(incu.com, dur.cat == "(3,4]")
      incu.com_dur <- filter(incu.com, dur.cat == "(4,6]")
      incu.com_dur <- filter(incu.com, dur.cat == "(6,41]")
      
      table(incu.com_dur$incu_import)

# Within the durations stratify by country:

## extract austrian data
      incu.com.aus <- incu.com_dur[which(incu.com_dur$incu_import == "Österreich"),]
      ## fit ln only on austrian data
      myfit.ln.aus <- ic_par(Surv(incu.com.aus$incumin, incu.com.aus$incumax, type="interval2") ~ 1,
                             data = incu.com.aus, dist = "lnorm")
      
      # parameter estimation
      meanlog.aus <- myfit.ln.aus$coefficients[1]
      sdlog.aus <- exp(myfit.ln.aus$coefficients[2])
      
      incqs.ln.aus <- getFitEsts(myfit.ln.aus, newdata = NULL, 
                                 p = c(0.025, 0.05, 0.25, 0.5, 0.75, 0.95, 0.975))
      myfit.ln.aus 
      
      survCIs(myfit.ln.aus, p = 0.5) 
      
      # mean:
      exp(myfit.ln.aus$coefficients[1] + 0.5*exp(myfit.ln.aus$coefficients[2])^2) 
      exp(meanlog.aus + 0.5*(sdlog.aus^2)) # this is the same as above, but more clear
      # sd
      # sqrt((exp(myfit.ln.aus$coefficients[2]^2) - 1) * exp(2*myfit.ln.aus$coefficients[1] + myfit.ln.aus$coefficients[2]^2))
      # the above line provides incorrect result of sd
      sqrt((exp(sdlog.aus^2) - 1)*exp(2*meanlog.aus + sdlog.aus^2)) # this should be the correct result

      ## extract italy data
      incu.com.it <- incu.com_dur[which(incu.com_dur$incu_import == "Italien"),]
      ## fit gamma only on italy data
      myfit.ln.it <- ic_par(Surv(incu.com.it$incumin, incu.com.it$incumax, type="interval2") ~ 1,
                            data = incu.com.it, dist = "lnorm")
      
      survCIs(myfit.ln.it, p = 0.5) 
      
      days <-  seq(0, 30, by = 0.05)
      
      # parameter estimation
      meanlog.it <- myfit.ln.it$coefficients[1]
      sdlog.it <- exp(myfit.ln.it$coefficients[2])
      
      incqs.ln.it <- getFitEsts(myfit.ln.it, newdata = NULL, 
                                p = c(0.025, 0.05, 0.25, 0.5, 0.75, 0.95, 0.975))
      myfit.ln.it 
      
      # mean:
      exp(myfit.ln.it$coefficients[1] + 0.5*exp(myfit.ln.it$coefficients[2])^2) 
      exp(meanlog.it + 0.5*(sdlog.it^2)) # this is the same as above, but more clear
      # sd
      #sqrt((exp(myfit.ln.it$coefficients[2]^2) - 1) * exp(2*myfit.ln.it$coefficients[1] + myfit.ln.it$coefficients[2]^2))
      # the above line provides incorrect result of sd
      sqrt((exp(sdlog.it^2) - 1)*exp(2*meanlog.it + sdlog.it^2)) # this should be the correct result
      


# get the confidence interval of our estimates using bootstrap: Austria

ci.aus <- survCIs(myfit.ln.aus, p = seq(0, 1, 0.0125)) 

ci.aus <- ci.aus$cis
ci.aus <- ci.aus$baseline
upper.aus <- ci.aus[,5]
lower.aus <- ci.aus[,4]

# Italy
ci.it <- survCIs(myfit.ln.it, p = seq(0, 1, 0.0125)) 

ci.it <- ci.it$cis
ci.it <- ci.it$baseline
upper.it <- ci.it[,5]
lower.it <- ci.it[,4]

# tmp data frame created using lognormal fits on austrian data
tmp_aus <- data.frame(days = days, 
                      fitsurv = 1 - plnorm(days, meanlog = myfit.ln.aus$coefficients[1],
                                           sdlog = exp(myfit.ln.aus$coefficients[2])))

# tmp data frame created using lognormal fits on italy data
tmp_ita <- data.frame(days = days, 
                      fitsurv = 1 - plnorm(days, meanlog = myfit.ln.it$coefficients[1],
                                           sdlog = exp(myfit.ln.it$coefficients[2])))


# confidence intervals: Austria
prob = seq(0, 1, 0.0125)
tmp.upper.aus <- data.frame(days = upper.aus,
                            fitsurv = 1- prob)
tmp.lower.aus <- data.frame(days = lower.aus,
                            fitsurv = 1- prob)
tmp.lower.aus <- tmp.lower.aus[2:80,]
tmp.upper.aus <- tmp.upper.aus[2:80,]

# confidence intervals: Italia
prob = seq(0, 1, 0.0125)
tmp.upper.it <- data.frame(days = upper.it,
                           fitsurv = 1- prob)
tmp.lower.it <- data.frame(days = lower.it,
                           fitsurv = 1- prob)
tmp.lower.it <- tmp.lower.it[2:80,]
tmp.upper.it <- tmp.upper.it[2:80,]



#    ggplot() + geom_line(data = tmp, aes(x = days, y = fitsurv), color = "#984ea3") +
#          geom_line(data = tmp_2, aes(x = days, y = fitsurv), color = "#4daf4a") +
#          geom_line(data = tmp.upper.aus, aes(x = days, y = fitsurv), color = "#984ea3", alpha = 0.7, linetype = "dashed") +
#          geom_line(data = tmp.lower.aus, aes(x = days, y = fitsurv), color = "#984ea3", alpha = 0.7, linetype = "dashed") +
#          geom_line(data = tmp.upper.it, aes(x = days, y = fitsurv), color = "#4daf4a", alpha = 0.7, linetype = "dashed") +
#          geom_line(data = tmp.lower.it, aes(x = days, y = fitsurv), color = "#4daf4a", alpha = 0.7, linetype = "dashed") 



short <- ggplot() +
  labs(x = "Days since exposure", y = "Proportion of cases with no symptoms yet")  +
  theme_classic() +
  scale_x_continuous(limits = c(0, 30)) +
  geom_line(data = tmp_aus, aes(x = days, y = fitsurv, color = "aus"), size = 1.5) + # , color = "#482173"
  geom_line(data = tmp_ita, aes(x = days, y = fitsurv, color = "ita"), size = 1.5) + #, color = "#2e6f8e"
  scale_color_manual(values = c("aus" = "#b2182b", "ita" = "#2166ac"),
                     name = "Country of importation",
                     label = c("aus" = "Austria", "ita" = "Italy")) +
  theme(legend.position = c(.75, .75)) +
  annotate("text", -Inf, Inf, hjust = -0.5, vjust = 1, label = "A", size = 8)  +
  geom_line(data = tmp.upper.aus, aes(x = days, y = fitsurv), color = "#b2182b", alpha = 0.7, linetype = "dashed") +
  geom_line(data = tmp.lower.aus, aes(x = days, y = fitsurv), color = "#b2182b", alpha = 0.7, linetype = "dashed") +
  geom_line(data = tmp.upper.it, aes(x = days, y = fitsurv), color = "#2166ac", alpha = 0.7, linetype = "dashed") +
  geom_line(data = tmp.lower.it, aes(x = days, y = fitsurv), color = "#2166ac", alpha = 0.7, linetype = "dashed") +
  labs(subtitle = "Duration of stay: 0 - 3 days")

low <- ggplot() +
  labs(x = "Days since exposure", y = "Proportion of cases with no symptoms yet")  +
  theme_classic() +
  scale_x_continuous(limits = c(0, 30)) +
  geom_line(data = tmp_aus, aes(x = days, y = fitsurv, color = "aus"), size = 1.5) + # , color = "#482173"
  geom_line(data = tmp_ita, aes(x = days, y = fitsurv, color = "ita"), size = 1.5) + #, color = "#2e6f8e"
  scale_color_manual(values = c("aus" = "#b2182b", "ita" = "#2166ac"),
                     name = "Country of importation",
                     label = c("aus" = "Austria", "ita" = "Italy")) +
  theme(legend.position = c(.75, .75)) +
  annotate("text", -Inf, Inf, hjust = -0.5, vjust = 1, label = "B", size = 8)  +
  geom_line(data = tmp.upper.aus, aes(x = days, y = fitsurv), color = "#b2182b", alpha = 0.7, linetype = "dashed") +
  geom_line(data = tmp.lower.aus, aes(x = days, y = fitsurv), color = "#b2182b", alpha = 0.7, linetype = "dashed") +
  geom_line(data = tmp.upper.it, aes(x = days, y = fitsurv), color = "#2166ac", alpha = 0.7, linetype = "dashed") +
  geom_line(data = tmp.lower.it, aes(x = days, y = fitsurv), color = "#2166ac", alpha = 0.7, linetype = "dashed") +
  labs(subtitle = "Duration of stay: 4 days")

higher <- ggplot() +
  labs(x = "Days since exposure", y = "Proportion of cases with no symptoms yet")  +
  theme_classic() +
  scale_x_continuous(limits = c(0, 30)) +
  geom_line(data = tmp_aus, aes(x = days, y = fitsurv, color = "aus"), size = 1.5) + # , color = "#482173"
  geom_line(data = tmp_ita, aes(x = days, y = fitsurv, color = "ita"), size = 1.5) + #, color = "#2e6f8e"
  scale_color_manual(values = c("aus" = "#b2182b", "ita" = "#2166ac"),
                     name = "Country of importation",
                     label = c("aus" = "Austria", "ita" = "Italy")) +
  theme(legend.position = c(.75, .75)) +
  annotate("text", -Inf, Inf, hjust = -0.5, vjust = 1, label = "C", size = 8)  +
  geom_line(data = tmp.upper.aus, aes(x = days, y = fitsurv), color = "#b2182b", alpha = 0.7, linetype = "dashed") +
  geom_line(data = tmp.lower.aus, aes(x = days, y = fitsurv), color = "#b2182b", alpha = 0.7, linetype = "dashed") +
  geom_line(data = tmp.upper.it, aes(x = days, y = fitsurv), color = "#2166ac", alpha = 0.7, linetype = "dashed") +
  geom_line(data = tmp.lower.it, aes(x = days, y = fitsurv), color = "#2166ac", alpha = 0.7, linetype = "dashed") +
  labs(subtitle = "Duration of stay: 5-6 days")

highest <- ggplot() +
  labs(x = "Days since exposure", y = "Proportion of cases with no symptoms yet")  +
  theme_classic() +
  scale_x_continuous(limits = c(0, 30)) +
  geom_line(data = tmp_aus, aes(x = days, y = fitsurv, color = "aus"), size = 1.5) + # , color = "#482173"
  geom_line(data = tmp_ita, aes(x = days, y = fitsurv, color = "ita"), size = 1.5) + #, color = "#2e6f8e"
  scale_color_manual(values = c("aus" = "#b2182b", "ita" = "#2166ac"),
                     name = "Country of importation",
                     label = c("aus" = "Austria", "ita" = "Italy")) +
  theme(legend.position = c(.75, .75)) +
  annotate("text", -Inf, Inf, hjust = -0.5, vjust = 1, label = "D", size = 8)  +
  geom_line(data = tmp.upper.aus, aes(x = days, y = fitsurv), color = "#b2182b", alpha = 0.7, linetype = "dashed") +
  geom_line(data = tmp.lower.aus, aes(x = days, y = fitsurv), color = "#b2182b", alpha = 0.7, linetype = "dashed") +
  geom_line(data = tmp.upper.it, aes(x = days, y = fitsurv), color = "#2166ac", alpha = 0.7, linetype = "dashed") +
  geom_line(data = tmp.lower.it, aes(x = days, y = fitsurv), color = "#2166ac", alpha = 0.7, linetype = "dashed") 

grid.arrange(short, low, higher, ncol = 3)




### serial interval estimation ####


serial$SI <- as.numeric(serial$second - serial$first)

#average
mean(serial$SI)
# range:
summary(serial$SI)

# figure
serial %>%
  ggplot() +
  geom_histogram(aes(x = dif), binwidth = 1, color = "white") +
  scale_x_continuous(breaks = c(seq(0, 15, 1))) +
  theme_classic() +
  scale_y_continuous(expand = c(0,0), breaks = c(seq(1,15,1))) +
  labs(x = "Serial interval")

serial$first_nr <- 0
serial$SI
serial$event <- 1

# visualize the data on a survival plot:

ggsurvplot(
  fit = survfit(Surv(time = first_nr, time2 = SI, event = event) ~ 1, 
                data = serial), 
  xlab = "Days",
  ylab = "Overall probability of no symptoms yet")


# fit different distributions
        set.seed(123)
        
        library(fitdistrplus)
        library(mixdist)
        
        descdist(serial$SI, boot = 1000)
        plotdist(serial$SI)
        
        fw <- fitdist(serial$SI, "weibull")
        fg <- fitdist(serial$SI, "gamma")
        fln <- fitdist(serial$SI, "lnorm")
        fn <- fitdist(serial$SI, "norm")
        plot.legend <- c("Weibull", "lognormal", "gamma", "normal")
        
        denscomp(list(fw,fg, fln, fn), xlab = "serial interval")
# goodness of fit

        fit.h <- gofstat(list(fw, fln, fg, fn), fitnames = plot.legend)
        fit.h

# gamma the best, followed by the Weibull

        # mean of gamma is scale * shape
        # scale: 1 / rate
        
        fg$estimate
        
        # mean: 
        fg$estimate[1] * (1/fg$estimate[2])
        # mean = 3.9
        # variance
        fg$estimate[1] * (1/fg$estimate[2])^2
        sqrt(fg$estimate[1] * (1/fg$estimate[2])^2)
        # sd = 2.2

# median:

x <- rgamma(n=1000,scale=1/fg$estimate[2],shape=fg$estimate[1])
mean(x)
sd(x)
quantile(x, probs = c(0, 0.05, 0.5, 0.95, 0.975))

# get the confidence interval:
boot.fg <- bootdist(fg, niter = 1000)
summary(boot.fg)
plot(boot.fg)
quantile(boot.fg, probs = 0.5)
quantile(boot.fg, probs = 0.025)
quantile(boot.fg, probs = 0.95)

# CI

cdfcomp(fg)
fitdistr(serial$SI, densfun = "gamma")


